@@ -1,45 +1,28 @@
 #' Download and crop the 1 (~30 meter) or 1/3 (~10 meter) arc-second National Elevation Dataset.
 #'
-#' \code{getNED} returns a \code{RasterLayer} of elevation data cropped to a given
+#' \code{get_ned} returns a \code{RasterLayer} of elevation data cropped to a given
 #' template study area.
 #'
 #' @param template A Raster* or Spatial* object to serve 
-#' as a template for cropping, and perhaps resolution. If a Raster* with
-#' a resolution that is less than 1/3 arc-second, \code{getNED} defaults to the 1/3 
-#' arc-second dataset. Otherwise, it defaults to the 1 arc-second dataset.
+#' as a template for cropping, and perhaps resolution.
 #' @param label A character string naming the study area.
 #' @param res A character string representing the desired resolution of the NED. "1"
-#' indicates the 1 arc-second NED, while "13" indicates the 1/3 arc-second dataset. Defaults to NULL.
+#' indicates the 1 arc-second NED (the default), while "13" indicates the 1/3 arc-second dataset.
 #' @param raw.dir A character string indicating where raw downloaded files should be put.
 #' The directory will be created if missing. Defaults to "./RAW/NED/".
 #' @param extraction.dir A character string indicating where the extracted and cropped DEM should be put.
 #' The directory will be created if missing. Defaults to "./EXTRACTIONS/NED/".
 #' @param force.redo If an extraction for this template and label already exists, should a new one be created?
 #' @return A \code{RasterLayer} DEM cropped to the extent of the template.
-getNED <- function(template, label, res=NULL, raw.dir="./RAW/NED/", extraction.dir="./EXTRACTIONS/NED/", force.redo=F){  
+get_ned <- function(template, label, res="1", raw.dir="./RAW/NED/", extraction.dir="./EXTRACTIONS/NED/", force.redo=F){  
   
   rasters.dir <- paste(extraction.dir,"/",label,"/rasters",sep='')
   
   dir.create(raw.dir, showWarnings = FALSE, recursive = TRUE)
   dir.create(rasters.dir, showWarnings = FALSE, recursive = TRUE)
   
-  # Convert polygon to decimal degrees for data request
-  extent.latlon <- raster::extent(raster::projectExtent(template, sp::CRS("+proj=longlat +ellps=WGS84")))
-  
-  if(is.null(res) & (class(template) %in% c("RasterLayer","RasterStack","RasterBrick"))){
-    y.dim <- extent.latlon@ymax - extent.latlon@ymin
-    y.res <- y.dim/nrow(template)
-    if(y.res < (1/60)/60){
-      res <- "13"
-    }else{
-      res <- "1"
-    }
-  }else if(is.null(res)){
-    warning("If template is a sp* or extent object, res should be provided! \n Defaulting to 1 arc-second NED.\n", immediate.=T)
-    res <- "1"
-  }
-  
-  template <- polygonFromExtent(extent.latlon,"+proj=longlat +ellps=WGS84")
+  template <- sp::spTransform(polygon_from_extent(template),sp::CRS("+proj=longlat +ellps=WGS84"))
+  extent.latlon <- extent(template)
   
   if(file.exists(paste(rasters.dir,"/NED_",res,".tif", sep='')) & !force.redo){
     extracted.DEM <- raster::raster(paste(rasters.dir,"/NED_",res,".tif", sep=''))
@@ -53,17 +36,17 @@ getNED <- function(template, label, res=NULL, raw.dir="./RAW/NED/", extraction.d
   
   tilesLocations <- as.matrix(expand.grid(norths,wests,stringsAsFactors = FALSE))
   
-  cat("\nArea of interest includes",nrow(tilesLocations),"NED tiles.\n")
+  message("Area of interest includes ",nrow(tilesLocations)," NED tiles.")
   
   # Download and crop tiles
   tiles <- apply(tilesLocations,1,function(loc){
-    return(getNEDTile(template=template, res=res, tileNorthing=loc[1], tileWesting=loc[2], raw.dir=raw.dir))
+    return(get_ned_tile(template=template, res=res, tileNorthing=loc[1], tileWesting=loc[2], raw.dir=raw.dir))
   })
   
   # Mosaic all tiles
   if(length(tiles)>1){
-    cat('\nMosaic-ing NED tiles.\n')
-    flush.console()
+    message('Mosaicking NED tiles.')
+    utils::flush.console()
     
     tiles$fun <- mean
     tiles <- do.call(raster::mosaic, tiles)
@@ -87,7 +70,7 @@ getNED <- function(template, label, res=NULL, raw.dir="./RAW/NED/", extraction.d
 #' Tiles are downloaded in zipped ESRI ArcGrid format. \code{downloadNED} returns the path to the downloaded zip file.
 #'
 #' @param res A character string representing the desired resolution of the NED. "1"
-#' indicates the 1 arc-second NED, while "13" indicates the 1/3 arc-second dataset. Defaults to NULL.
+#' indicates the 1 arc-second NED (the default), while "13" indicates the 1/3 arc-second dataset.
 #' @param tileNorthing An integer representing the northing (latitude, in degrees north of the equator) of the northwest corner of the tile to 
 #' be downloaded.
 #' @param tileWesting An integer representing the westing (longitude, in degrees west of the prime meridian) of the northwest corner of the tile to 
@@ -95,11 +78,7 @@ getNED <- function(template, label, res=NULL, raw.dir="./RAW/NED/", extraction.d
 #' @param raw.dir A character string indicating where raw downloaded files should be put.
 #' The directory will be created if missing. Defaults to "./RAW/NED/".
 #' @return A character string representing the full local path of the downloaded directory.
-downloadNEDTile <- function(res=NULL, tileNorthing, tileWesting, raw.dir){
-  if(is.null(res)){
-    warning("If template is a sp* or extent object, res should be provided! \n Defaulting to 1 arc-second NED.\n", immediate.=T)
-    res <- "1"
-  }
+download_ned_tile <- function(res="1", tileNorthing, tileWesting, raw.dir){
   
   destdir <- paste(raw.dir,'/',res, sep='')
   
@@ -110,20 +89,20 @@ downloadNEDTile <- function(res=NULL, tileNorthing, tileWesting, raw.dir){
   
   url <- paste('ftp://rockyftp.cr.usgs.gov/vdelivery/Datasets/Staged/NED/',res,'/ArcGrid/n',tileNorthing,'w',tileWesting,'.zip',sep='')
   destdir <- paste(raw.dir,'/',res,'/',sep='')
-  curlDownload(url=url, destdir=destdir)
+  curl_download(url=url, destdir=destdir)
   
   return(normalizePath(paste(destdir,'n',tileNorthing,'w',tileWesting,'.zip',sep='')))
 }
 
 #' Download and crop tile from the 1 (~30 meter) or 1/3 (~10 meter) arc-second National Elevation Dataset.
 #'
-#' \code{getNEDTile} returns a \code{RasterLayer} cropped within the specified \code{template}.
+#' \code{get_ned_tile} returns a \code{RasterLayer} cropped within the specified \code{template}.
 #' If template is not provided, returns the entire NED tile.
 #' 
 #' @param template A Raster* or Spatial* object to serve 
-#' as a template for cropping.
+#' as a template for cropping. If missing, entire tile is returned.
 #' @param res A character string representing the desired resolution of the NED. "1"
-#' indicates the 1 arc-second NED, while "13" indicates the 1/3 arc-second dataset. Defaults to NULL.
+#' indicates the 1 arc-second NED (the default), while "13" indicates the 1/3 arc-second dataset.
 #' @param tileNorthing An integer representing the northing (latitude, in degrees north of the equator) of the northwest corner of the tile to 
 #' be downloaded.
 #' @param tileWesting An integer representing the westing (longitude, in degrees west of the prime meridian) of the northwest corner of the tile to 
@@ -131,27 +110,29 @@ downloadNEDTile <- function(res=NULL, tileNorthing, tileWesting, raw.dir){
 #' @param raw.dir A character string indicating where raw downloaded files should be put.
 #' The directory will be created if missing. Defaults to "./RAW/NED/".
 #' @return A \code{RasterLayer} cropped within the specified \code{template}.
-getNEDTile <- function(template=NULL, res, tileNorthing, tileWesting, raw.dir){
+get_ned_tile <- function(template=NULL, res="1", tileNorthing, tileWesting, raw.dir){
   tmpdir <- tempfile()
   if (!dir.create(tmpdir))
     stop("failed to create my temporary directory")
   
-  cat("\n(Down)Loading NED tile for",tileNorthing,"N and",tileWesting,"W.")
+  message("(Down)Loading NED tile for ",tileNorthing,"N and ",tileWesting,"W.")
   
-  file <- downloadNEDTile(res=res, tileNorthing=tileNorthing, tileWesting=tileWesting, raw.dir=raw.dir)
+  file <- download_ned_tile(res=res, tileNorthing=tileNorthing, tileWesting=tileWesting, raw.dir=raw.dir)
   
-  unzip(file,exdir=tmpdir)
+  utils::unzip(file,exdir=tmpdir)
   
   dirs <- list.dirs(tmpdir,full.names = TRUE,recursive=F)
   dirs <- dirs[grepl("grdn",dirs)]
   
-  tile <- raster::raster(rgdal::readGDAL(dirs, silent=T))
-  
-  unlink(tmpdir, recursive = TRUE)
+  tile <- raster::raster(dirs)
   
   if(!is.null(template)){
-    tryCatch(tile <- raster::crop(tile,sp::spTransform(template,sp::CRS(raster::projection(tile))), snap="out"), error=function(e){tile <- raster::crop(tile,sp::spTransform(template,sp::CRS(raster::projection(tile))))})
+    tile <- tryCatch(raster::crop(tile,sp::spTransform(template,sp::CRS(raster::projection(tile))), snap="out"), error=function(e){raster::crop(tile,sp::spTransform(template,sp::CRS(raster::projection(tile))))})
   }
   
+  tile <- tile*1
+  
+  unlink(tmpdir, recursive = TRUE)
+   
   return(tile)
 }
\ No newline at end of file
