@@ -3,7 +3,7 @@
 #'This is a convenience function that checks whether a package is installed, and if not, installs it.
 #'
 #' @param x A character string representing the name of a package.
-pkgTest <- function(x){
+pkg_test <- function(x){
   if(grepl("/",x)){
     pkgName <- basename(x)
   }else{
@@ -14,7 +14,7 @@ pkgTest <- function(x){
     if(grepl("/",x)){
       suppressWarnings(devtools::install_github(x))
     }else{
-      install.packages(x,dependencies=TRUE, repos="http://cran.rstudio.com")
+      utils::install.packages(x,dependencies=TRUE, repos="http://cran.rstudio.com")
     }
   }
   if(!suppressWarnings(require(pkgName,character.only = TRUE))) stop("Package not found")
@@ -25,7 +25,7 @@ pkgTest <- function(x){
 #' @param x A character string.
 #' @param n The number of characters to retrieve.
 #' @return A character string.
-substrRight <- function(x, n){
+substr_right <- function(x, n){
   substr(x, nchar(x)-n+1, nchar(x))
 }
 
@@ -35,7 +35,7 @@ substrRight <- function(x, n){
 #' @param proj4string A PROJ.4 formatted string defining the required projection. If NULL, 
 #' the function will attempt to get the projection from x using \code{\link{projection}}
 #' @return A SpatialPolygons object.
-polygonFromExtent <- function(x, proj4string=NULL){
+polygon_from_extent <- function(x, proj4string=NULL){
   if(is.null(proj4string)){
     proj4string <- raster::projection(x)
   }
@@ -53,8 +53,8 @@ polygonFromExtent <- function(x, proj4string=NULL){
 #'
 #' @param x An SpatialPolygons object.
 #' @return A SpatialPolygonsDataFrame object.
-SPDFfromPolygon <- function(x){
-  IDs <- sapply(slot(x, "polygons"), function(x) slot(x, "ID"))
+spdf_from_polygon <- function(x){
+  IDs <- sapply((methods::slot(x, "polygons")), function(x){methods::slot(x, "ID")})
   df <- data.frame(rep(0, length(IDs)), row.names=IDs)
   x <- sp::SpatialPolygonsDataFrame(x,df)
   return(x)
@@ -65,7 +65,7 @@ SPDFfromPolygon <- function(x){
 #' @param x An vector of any type, or, if \code{rows}, a matrix.
 #' @param rows Is x a matrix?
 #' @return A logical vector of the same length as x.
-sequential.duplicated <- function(x, rows=F){
+sequential_duplicated <- function(x, rows=F){
   if(!rows){
     duplicates <- c(FALSE,unlist(lapply(1:(length(x)-1), function(i){duplicated(x[i:(i+1)])[2]})))
   }else{
@@ -74,35 +74,9 @@ sequential.duplicated <- function(x, rows=F){
   return(duplicates)
 }
 
-#'Use the \code{wget} command line tool to download a file.
-#'
-#' If both \code{timestamping} and \code{nc} are TRUE, timestamping behavior trumps nc.
-#'
-#' @param url The location of a file.
-#' @param destdir Where the file should be downloaded to.
-#' @param timestamping Should only newer files be downloaded?
-#' @param nc Should files of the same type not be clobbered?
-#' @return A logical vector of the same length as x.
-wgetDownload <- function(url, destdir=getwd(), timestamping=T, nc=F){
-  destdir <- gsub(" ","\\ ",destdir, fixed=T)
-  if(!any(c(timestamping,nc))){
-    status <- system(paste("wget -nd --quiet --directory-prefix=",destdir," ",url,sep=''))
-  }else if(timestamping){
-    status <- system(paste("wget -N -nd --quiet --directory-prefix=",destdir," ",url,sep=''))
-  }else{
-    status <- system(paste("wget -nc -nd --quiet --directory-prefix=",destdir," ",url,sep=''))
-  }
-  
-  # If status is still not zero, report a warning
-  if (status!=0)
-    warning("Download of ",url," had nonzero exit status")
-}
-
 #' Use RCurl to download a file.
 #'
 #' This function makes it easy to implement timestamping and no-clobber of files.
-#' Unlike \link{wgetDownload}, it doesn't require an external command-line tool to 
-#' be installed.
 #'
 #' If both \code{timestamping} and \code{nc} are TRUE, nc behavior trumps timestamping.
 #'
@@ -113,19 +87,18 @@ wgetDownload <- function(url, destdir=getwd(), timestamping=T, nc=F){
 #' @param verbose Should cURL output be shown?
 #' @param progress Should a progress bar be shown with cURL output?
 #' @return A logical vector of the same length as x.
-curlDownload <- function(url, destdir=getwd(), timestamping=T, nc=F, verbose=F, progress=F){
+curl_download <- function(url, destdir=getwd(), timestamping=T, nc=F, verbose=F, progress=F){
   
   destdir <- normalizePath(destdir)
   destfile <- paste0(destdir,'/',basename(url))
-  #   destfile <- gsub(" ","\\ ",destfile, fixed=T)
   
   if(nc & file.exists(destfile)) return()
   
   if(timestamping & file.exists(destfile)){
-    cat("\nDownloading file (if necessary):",url,"\n")
+    message("Downloading file (if necessary): ",url)
     temp.file <- paste0(tempdir(),"/",basename(url))
-    f <- CFILE(temp.file, "wb")
-    status <- curlPerform(url = url, 
+    f <- RCurl::CFILE(temp.file, "wb")
+    status <- RCurl::curlPerform(url = url, 
                           writedata = f@ref,
                           verbose=verbose,
                           noprogress=!progress,
@@ -134,24 +107,24 @@ curlDownload <- function(url, destdir=getwd(), timestamping=T, nc=F, verbose=F,
                           forbid.reuse=T, 
                           timecondition=T, 
                           timevalue=base::file.info(destfile)$mtime)
-    close(f)
+    RCurl::close(f)
     if(file.info(temp.file)$size > 0){
       file.copy(temp.file,destfile, overwrite=T)
     }
     
     #     status <- system(paste0("curl -R --globoff --create-dirs -z ",destfile," --url ",url," --output ",destfile))
   }else{
-    cat("\nDownloading file:",url,"\n")
+    message("Downloading file: ",url)
     temp.file <- paste0(tempdir(),"/",basename(url))
-    f <- CFILE(temp.file, "wb")
-    status <- curlPerform(url = url, 
+    f <- RCurl::CFILE(temp.file, "wb")
+    status <- RCurl::curlPerform(url = url, 
                           writedata = f@ref,
                           verbose=verbose,
                           noprogress=!progress,
                           fresh.connect=T, 
                           ftp.use.epsv=F, 
                           forbid.reuse=T)
-    close(f)
+    RCurl::close(f)
     file.copy(temp.file,destfile, overwrite=T)
     
     
